Class: MessenteApi::Viber
- Inherits:
-
Object
- Object
- MessenteApi::Viber
- Defined in:
- lib/messente_api/models/viber.rb
Overview
Viber message content. You must provide one of these combinations: * image_url * text * text, button_text and button_url * text, image_url, button_text and button_url * video * video, text * video, text, button_text * video, text, button_text and button_url * carousel and text
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#button_text ⇒ Object
Must be specified along with ''text'', ''button_url'', ''button_text'', ''image_url'' (optional).
-
#button_url ⇒ Object
URL of the button, must be specified along with ''text'', ''button_text'' and ''image_url'' (optional).
-
#carousel ⇒ Object
Returns the value of attribute carousel.
-
#channel ⇒ Object
The channel used to deliver the message.
-
#image_url ⇒ Object
URL for the embedded image.
-
#sender ⇒ Object
Phone number or alphanumeric sender name.
-
#template ⇒ Object
Returns the value of attribute template.
-
#text ⇒ Object
Plaintext content for Viber.
-
#ttl ⇒ Object
After how many seconds this channel is considered as failed and the next channel is attempted.
-
#validity ⇒ Object
After how many minutes this channel is considered as failed and the next channel is attempted.
-
#video ⇒ Object
Returns the value of attribute video.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Viber
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Viber
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/messente_api/models/viber.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MessenteApi::Viber` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MessenteApi::Viber`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'sender') self.sender = attributes[:'sender'] end if attributes.key?(:'validity') self.validity = attributes[:'validity'] end if attributes.key?(:'ttl') self.ttl = attributes[:'ttl'] end if attributes.key?(:'text') self.text = attributes[:'text'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'button_url') self. = attributes[:'button_url'] end if attributes.key?(:'button_text') self. = attributes[:'button_text'] end if attributes.key?(:'channel') self.channel = attributes[:'channel'] else self.channel = 'viber' end if attributes.key?(:'video') self.video = attributes[:'video'] end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'carousel') self.carousel = attributes[:'carousel'] end end |
Instance Attribute Details
#button_text ⇒ Object
Must be specified along with ''text'', ''button_url'', ''button_text'', ''image_url'' (optional)
38 39 40 |
# File 'lib/messente_api/models/viber.rb', line 38 def @button_text end |
#button_url ⇒ Object
URL of the button, must be specified along with ''text'', ''button_text'' and ''image_url'' (optional)
35 36 37 |
# File 'lib/messente_api/models/viber.rb', line 35 def @button_url end |
#carousel ⇒ Object
Returns the value of attribute carousel.
47 48 49 |
# File 'lib/messente_api/models/viber.rb', line 47 def carousel @carousel end |
#channel ⇒ Object
The channel used to deliver the message
41 42 43 |
# File 'lib/messente_api/models/viber.rb', line 41 def channel @channel end |
#image_url ⇒ Object
URL for the embedded image.
32 33 34 |
# File 'lib/messente_api/models/viber.rb', line 32 def image_url @image_url end |
#sender ⇒ Object
Phone number or alphanumeric sender name
20 21 22 |
# File 'lib/messente_api/models/viber.rb', line 20 def sender @sender end |
#template ⇒ Object
Returns the value of attribute template.
45 46 47 |
# File 'lib/messente_api/models/viber.rb', line 45 def template @template end |
#text ⇒ Object
Plaintext content for Viber
29 30 31 |
# File 'lib/messente_api/models/viber.rb', line 29 def text @text end |
#ttl ⇒ Object
After how many seconds this channel is considered as failed and the next channel is attempted. Only one of "ttl" and "validity" can be used.
26 27 28 |
# File 'lib/messente_api/models/viber.rb', line 26 def ttl @ttl end |
#validity ⇒ Object
After how many minutes this channel is considered as failed and the next channel is attempted. Only one of "ttl" and "validity" can be used.
23 24 25 |
# File 'lib/messente_api/models/viber.rb', line 23 def validity @validity end |
#video ⇒ Object
Returns the value of attribute video.
43 44 45 |
# File 'lib/messente_api/models/viber.rb', line 43 def video @video end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/messente_api/models/viber.rb', line 262 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = MessenteApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/messente_api/models/viber.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/messente_api/models/viber.rb', line 72 def self.attribute_map { :'sender' => :'sender', :'validity' => :'validity', :'ttl' => :'ttl', :'text' => :'text', :'image_url' => :'image_url', :'button_url' => :'button_url', :'button_text' => :'button_text', :'channel' => :'channel', :'video' => :'video', :'template' => :'template', :'carousel' => :'carousel' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/messente_api/models/viber.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/messente_api/models/viber.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/messente_api/models/viber.rb', line 94 def self.openapi_types { :'sender' => :'String', :'validity' => :'Integer', :'ttl' => :'Integer', :'text' => :'String', :'image_url' => :'String', :'button_url' => :'String', :'button_text' => :'String', :'channel' => :'String', :'video' => :'ViberVideo', :'template' => :'ViberTemplate', :'carousel' => :'ViberCarousel' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/messente_api/models/viber.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && sender == o.sender && validity == o.validity && ttl == o.ttl && text == o.text && image_url == o.image_url && == o. && == o. && channel == o.channel && video == o.video && template == o.template && carousel == o.carousel end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/messente_api/models/viber.rb', line 333 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/messente_api/models/viber.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/messente_api/models/viber.rb', line 231 def hash [sender, validity, ttl, text, image_url, , , channel, video, template, carousel].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 |
# File 'lib/messente_api/models/viber.rb', line 180 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
309 310 311 |
# File 'lib/messente_api/models/viber.rb', line 309 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/messente_api/models/viber.rb', line 315 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
303 304 305 |
# File 'lib/messente_api/models/viber.rb', line 303 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 |
# File 'lib/messente_api/models/viber.rb', line 188 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' channel_validator = EnumAttributeValidator.new('String', ["viber"]) return false unless channel_validator.valid?(@channel) true end |