Class: MessenteApi::RcsSuggestedAction
- Inherits:
-
Object
- Object
- MessenteApi::RcsSuggestedAction
- Defined in:
- lib/messente_api/models/rcs_suggested_action.rb
Overview
RCS suggested action.
Instance Attribute Summary collapse
-
#create_calendar_event_action ⇒ Object
Returns the value of attribute create_calendar_event_action.
-
#dial_action ⇒ Object
Returns the value of attribute dial_action.
-
#fallback_url ⇒ Object
The fallback URL to open if the suggested action is not supported.
-
#open_url_action ⇒ Object
Returns the value of attribute open_url_action.
-
#postback_data ⇒ Object
The postback data associated with the suggested action.
-
#share_location_action ⇒ Object
This action does not have any properties.
-
#text ⇒ Object
The text of the suggested action.
-
#view_location_action ⇒ Object
Returns the value of attribute view_location_action.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RcsSuggestedAction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RcsSuggestedAction
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MessenteApi::RcsSuggestedAction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MessenteApi::RcsSuggestedAction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'postback_data') self.postback_data = attributes[:'postback_data'] else self.postback_data = nil end if attributes.key?(:'fallback_url') self.fallback_url = attributes[:'fallback_url'] end if attributes.key?(:'dial_action') self.dial_action = attributes[:'dial_action'] end if attributes.key?(:'view_location_action') self.view_location_action = attributes[:'view_location_action'] end if attributes.key?(:'create_calendar_event_action') self.create_calendar_event_action = attributes[:'create_calendar_event_action'] end if attributes.key?(:'open_url_action') self.open_url_action = attributes[:'open_url_action'] end if attributes.key?(:'share_location_action') self.share_location_action = attributes[:'share_location_action'] end end |
Instance Attribute Details
#create_calendar_event_action ⇒ Object
Returns the value of attribute create_calendar_event_action.
32 33 34 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 32 def create_calendar_event_action @create_calendar_event_action end |
#dial_action ⇒ Object
Returns the value of attribute dial_action.
28 29 30 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 28 def dial_action @dial_action end |
#fallback_url ⇒ Object
The fallback URL to open if the suggested action is not supported.
26 27 28 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 26 def fallback_url @fallback_url end |
#open_url_action ⇒ Object
Returns the value of attribute open_url_action.
34 35 36 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 34 def open_url_action @open_url_action end |
#postback_data ⇒ Object
The postback data associated with the suggested action. This is sent back to the sender when the user selects the suggested action.
23 24 25 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 23 def postback_data @postback_data end |
#share_location_action ⇒ Object
This action does not have any properties. It simply triggers the share location action.
37 38 39 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 37 def share_location_action @share_location_action end |
#text ⇒ Object
The text of the suggested action. Exactly one of the action fields (types) must be provided.
20 21 22 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 20 def text @text end |
#view_location_action ⇒ Object
Returns the value of attribute view_location_action.
30 31 32 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 30 def view_location_action @view_location_action end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 263 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = MessenteApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 54 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 40 def self.attribute_map { :'text' => :'text', :'postback_data' => :'postback_data', :'fallback_url' => :'fallback_url', :'dial_action' => :'dial_action', :'view_location_action' => :'view_location_action', :'create_calendar_event_action' => :'create_calendar_event_action', :'open_url_action' => :'open_url_action', :'share_location_action' => :'share_location_action' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 239 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 77 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 73 def self.openapi_nullable Set.new([ :'fallback_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 59 def self.openapi_types { :'text' => :'String', :'postback_data' => :'String', :'fallback_url' => :'String', :'dial_action' => :'RcsDialAction', :'view_location_action' => :'RcsViewLocationAction', :'create_calendar_event_action' => :'RcsCreateCalendarEventAction', :'open_url_action' => :'RcsOpenUrlAction', :'share_location_action' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && text == o.text && postback_data == o.postback_data && fallback_url == o.fallback_url && dial_action == o.dial_action && view_location_action == o.view_location_action && create_calendar_event_action == o.create_calendar_event_action && open_url_action == o.open_url_action && share_location_action == o.share_location_action end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 232 def hash [text, postback_data, fallback_url, dial_action, view_location_action, create_calendar_event_action, open_url_action, share_location_action].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @text.nil? invalid_properties.push('invalid value for "text", text cannot be nil.') end if @text.to_s.length > 25 invalid_properties.push('invalid value for "text", the character length must be smaller than or equal to 25.') end if @postback_data.nil? invalid_properties.push('invalid value for "postback_data", postback_data cannot be nil.') end if @postback_data.to_s.length > 2048 invalid_properties.push('invalid value for "postback_data", the character length must be smaller than or equal to 2048.') end if !@fallback_url.nil? && @fallback_url.to_s.length > 2048 invalid_properties.push('invalid value for "fallback_url", the character length must be smaller than or equal to 2048.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
310 311 312 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 310 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 304 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 |
# File 'lib/messente_api/models/rcs_suggested_action.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @text.nil? return false if @text.to_s.length > 25 return false if @postback_data.nil? return false if @postback_data.to_s.length > 2048 return false if !@fallback_url.nil? && @fallback_url.to_s.length > 2048 true end |